from xerparser.model.classes.calendar_data import CalendarData


class Calendar:

    obj_list = []
    working_days = dict()
    exceptions = []

    def __init__(self, params):
        # Unique ID generated by the system.
        self.clndr_id = int(params[0]) if params[0] else None
        # Identifies the default global calendar (applies to global calendars only).
        self.default_flag = params[1].strip()
        # The name of the calendar.
        self.clndr_name = params[2].strip()
        self.proj_id = params[3].strip()
        # The global calendar to which this calendar is linked.  Any changes to the global calendar are automatically
        #  propagated to this calendar.
        self.base_clndr_id = params[4].strip()
        # Date of last changes to calendar.
        self.last_chng_date = params[5].strip()
        # The calendar type - either global, resource, or project. Global calendars can be assigned to projects and
        # resources. Resource calendars can be assigned only to resources. Project calendars are specific to projects.
        self.clndr_type = params[6].strip()
        # The number of work hours per day. This conversion factor is used for displaying time units and durations in
        #  the user's selected display formats.
        self.day_hr_cnt = float(params[7]) if params[7] else None
        # The number of work hours per week. This conversion factor is used for displaying time units and durations
        # in the user's selected display formats.
        self.week_hr_cnt = float(params[8]) if params[8] else None
        # The number of work hours per month. This conversion factor is used for displaying time units and durations
        # in the user's selected display formats.
        self.month_hr_cnt = float(params[9]) if params[9] else None
        # The number of work hours per year. This conversion factor is used for displaying time units and durations
        # in the user's selected display formats.
        self.year_hr_cnt = float(params[10]) if params[10] else None
        #
        self.rsrc_private = params[11].strip()

        self.clndr_data = params[12].strip()
        c = CalendarData(self.clndr_data)
        self.working_days = c.get_days()
        self.exceptions = c.get_exceptions()
        Calendar.obj_list.append(self)

    def get_id(self):
        return self.clndr_id

    @classmethod
    def find_by_id(cls, id):
        obj = list(filter(lambda x: x.clndr_id == id, cls.obj_list))
        if obj:
            return obj[0]
        return None

    def __repr__(self):
        return self.clndr_name + ' : ' + str(self.day_hr_cnt) + '\n' + self.clndr_data